@@ -45,6 +45,7 @@
 	1.1.8   KRE     20040807        Add support for HIGHMEM
 	1.1.8   KRE     20010201        Added sh (Nobuhiro Iwamatsu)
 	1.1.8   KRE     20010201        Added avr32
+	1.1.8   AB      20220529        Added RiscV
 
 */
 
@@ -103,6 +104,10 @@
 #define system_avr32
 #endif
 
+#if defined(__riscv)
+#define system_riscv
+#endif
+
 #if (SIZEOF_LONG > 4)
 #define LONGLONG long int
 #define LONGSPEC "%ld"
